@@ -1,6 +1,8 @@
+from typing import Union
+
 from aio_pika.patterns import (
     JsonRPC,
     RPC,
 )
 
-UnionRpc = JsonRPC | RPC
+UnionRpc = Union[JsonRPC, RPC]
